# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`consul`](#consul): Installs, configures and manages consul

#### Private Classes

* `consul::config`: This class is called from consul::init to install the config file.
* `consul::install`: Installs consul based on the parameters from init
* `consul::params`: == Class consul::params  This class is meant to be called from consul It sets variables according to platform
* `consul::reload_service`: This class is meant to be called from certain configuration changes that support reload.
* `consul::run_service`: This class is meant to be called from consul. It ensures the service is running
* `consul::windows_service`: Installs consul windows server

### Defined types

* [`consul::check`](#consul--check): Sets up a Consul healthcheck
* [`consul::service`](#consul--service): Sets up a Consul service definition
* [`consul::watch`](#consul--watch): Sets up Consul watch, to span commands when data changes.

### Resource types

* [`consul_acl`](#consul_acl): Manage a consul token and its ACLs.
* [`consul_key_value`](#consul_key_value): Manage a consul key value object.
* [`consul_policy`](#consul_policy): Manages a Consul ACL policy
* [`consul_prepared_query`](#consul_prepared_query): Manage a consul prepared query.
* [`consul_token`](#consul_token): Manages a v2 Consul token

### Functions

* [`consul::sorted_json`](#consul--sorted_json)
* [`consul::validate_checks`](#consul--validate_checks)

### Data types

* [`Consul::PolicyStruct`](#Consul--PolicyStruct)
* [`Consul::TokenStruct`](#Consul--TokenStruct)

## Classes

### <a name="consul"></a>`consul`

Installs, configures and manages consul

#### Examples

##### simple consul setup

```puppet
class { 'consul':
  config_hash => {
    'datacenter'   => 'east-aws',
    'node_name'    => $facts['fqdn'],
    'pretty_config => true,
    'retry-join'   => ['172.16.0.1'],
  },
}
```

#### Parameters

The following parameters are available in the `consul` class:

* [`acls`](#-consul--acls)
* [`tokens`](#-consul--tokens)
* [`policies`](#-consul--policies)
* [`acl_api_hostname`](#-consul--acl_api_hostname)
* [`acl_api_protocol`](#-consul--acl_api_protocol)
* [`acl_api_port`](#-consul--acl_api_port)
* [`acl_api_tries`](#-consul--acl_api_tries)
* [`acl_api_token`](#-consul--acl_api_token)
* [`arch`](#-consul--arch)
* [`archive_path`](#-consul--archive_path)
* [`bin_dir`](#-consul--bin_dir)
* [`binary_group`](#-consul--binary_group)
* [`binary_mode`](#-consul--binary_mode)
* [`binary_name`](#-consul--binary_name)
* [`binary_owner`](#-consul--binary_owner)
* [`checks`](#-consul--checks)
* [`config_defaults`](#-consul--config_defaults)
* [`config_dir`](#-consul--config_dir)
* [`config_name`](#-consul--config_name)
* [`config_hash`](#-consul--config_hash)
* [`config_mode`](#-consul--config_mode)
* [`config_owner`](#-consul--config_owner)
* [`data_dir_mode`](#-consul--data_dir_mode)
* [`docker_image`](#-consul--docker_image)
* [`download_extension`](#-consul--download_extension)
* [`download_url`](#-consul--download_url)
* [`download_url_base`](#-consul--download_url_base)
* [`extra_groups`](#-consul--extra_groups)
* [`extra_options`](#-consul--extra_options)
* [`group`](#-consul--group)
* [`init_style`](#-consul--init_style)
* [`install_method`](#-consul--install_method)
* [`join_wan`](#-consul--join_wan)
* [`manage_group`](#-consul--manage_group)
* [`manage_repo`](#-consul--manage_repo)
* [`manage_service`](#-consul--manage_service)
* [`manage_user`](#-consul--manage_user)
* [`manage_user_home_location`](#-consul--manage_user_home_location)
* [`manage_data_dir`](#-consul--manage_data_dir)
* [`os`](#-consul--os)
* [`package_ensure`](#-consul--package_ensure)
* [`package_name`](#-consul--package_name)
* [`pretty_config`](#-consul--pretty_config)
* [`pretty_config_indent`](#-consul--pretty_config_indent)
* [`proxy_server`](#-consul--proxy_server)
* [`purge_config_dir`](#-consul--purge_config_dir)
* [`restart_on_change`](#-consul--restart_on_change)
* [`service_enable`](#-consul--service_enable)
* [`service_ensure`](#-consul--service_ensure)
* [`services`](#-consul--services)
* [`user`](#-consul--user)
* [`version`](#-consul--version)
* [`watches`](#-consul--watches)
* [`shell`](#-consul--shell)
* [`enable_beta_ui`](#-consul--enable_beta_ui)
* [`allow_binding_to_root_ports`](#-consul--allow_binding_to_root_ports)
* [`log_file`](#-consul--log_file)

##### <a name="-consul--acls"></a>`acls`

Data type: `Hash`

Hash of consul_acl resources to create.

Default value: `{}`

##### <a name="-consul--tokens"></a>`tokens`

Data type: `Hash[String[1], Consul::TokenStruct]`

Hash of consul_token resources to create.

Default value: `{}`

##### <a name="-consul--policies"></a>`policies`

Data type: `Hash[String[1], Consul::PolicyStruct]`

Hash of consul_policy resources to create.

Default value: `{}`

##### <a name="-consul--acl_api_hostname"></a>`acl_api_hostname`

Data type: `String[1]`

Global hostname of ACL API, will be merged with consul_token resources

Default value: `'localhost'`

##### <a name="-consul--acl_api_protocol"></a>`acl_api_protocol`

Data type: `String[1]`

Global protocl of ACL API, will be merged with consul_token resources

Default value: `'http'`

##### <a name="-consul--acl_api_port"></a>`acl_api_port`

Data type: `Integer[1, 65535]`

Global port of ACL API, will be merged with consul_token resources

Default value: `8500`

##### <a name="-consul--acl_api_tries"></a>`acl_api_tries`

Data type: `Integer[1]`

Global max. tries of ACL API, will be merged with consul_token resources

Default value: `3`

##### <a name="-consul--acl_api_token"></a>`acl_api_token`

Data type: `String[0]`

Global token of ACL API, will be merged with consul_token resources

Default value: `''`

##### <a name="-consul--arch"></a>`arch`

Data type: `String[1]`

Architecture of consul binary to download

Default value: `$consul::params::arch`

##### <a name="-consul--archive_path"></a>`archive_path`

Data type: `Optional[Stdlib::Absolutepath]`

Path used when installing consul via the url

Default value: `undef`

##### <a name="-consul--bin_dir"></a>`bin_dir`

Data type: `Stdlib::Absolutepath`

Directory to create the symlink to the consul binary in.

Default value: `$consul::params::bin_dir`

##### <a name="-consul--binary_group"></a>`binary_group`

Data type: `Optional[String[1]]`

The group that the file belongs to.

Default value: `$consul::params::binary_group`

##### <a name="-consul--binary_mode"></a>`binary_mode`

Data type: `String[1]`

Permissions mode for the file.

Default value: `$consul::params::binary_mode`

##### <a name="-consul--binary_name"></a>`binary_name`

Data type: `String[1]`

The binary name file.

Default value: `$consul::params::binary_name`

##### <a name="-consul--binary_owner"></a>`binary_owner`

Data type: `String[1]`

The user that owns the file.

Default value: `$consul::params::binary_owner`

##### <a name="-consul--checks"></a>`checks`

Data type: `Hash`

Hash of consul::check resources to create.

Default value: `{}`

##### <a name="-consul--config_defaults"></a>`config_defaults`

Data type: `Hash`

Configuration defaults hash. Gets merged with config_hash.

Default value: `$consul::params::config_defaults`

##### <a name="-consul--config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

Directory to place consul configuration files in.

Default value: `$consul::params::config_dir`

##### <a name="-consul--config_name"></a>`config_name`

Data type: `String[1]`

Name of the consul configuration file.

Default value: `'config.json'`

##### <a name="-consul--config_hash"></a>`config_hash`

Data type: `Variant[Hash,Sensitive[Hash]]`

Use this to populate the JSON config file for consul.

Default value: `{}`

##### <a name="-consul--config_mode"></a>`config_mode`

Data type: `String[1]`

Use this to set the JSON config file mode for consul.

Default value: `'0664'`

##### <a name="-consul--config_owner"></a>`config_owner`

Data type: `Optional[String[1]]`

The user that owns the config_dir directory and its files.

Default value: `undef`

##### <a name="-consul--data_dir_mode"></a>`data_dir_mode`

Data type: `String[1]`

Use this to set the data_dir directory mode for consul.

Default value: `$consul::params::data_dir_mode`

##### <a name="-consul--docker_image"></a>`docker_image`

Data type: `String[1]`

Only valid when the install_method == docker. Defaults to `consul`.

Default value: `'consul'`

##### <a name="-consul--download_extension"></a>`download_extension`

Data type: `String[1]`

The extension of the archive file containing the consul binary to download.

Default value: `'zip'`

##### <a name="-consul--download_url"></a>`download_url`

Data type: `Optional[Stdlib::Filesource]`

Fully qualified url, puppet uri or absolute path to the location of the archive file containing the consul binary.

Default value: `undef`

##### <a name="-consul--download_url_base"></a>`download_url_base`

Data type: `String[1]`

Base url to the location of the archive file containing the consul binary.

Default value: `'https://releases.hashicorp.com/consul/'`

##### <a name="-consul--extra_groups"></a>`extra_groups`

Data type: `Array`

Extra groups to add the consul system user to.

Default value: `[]`

##### <a name="-consul--extra_options"></a>`extra_options`

Data type: `Optional[String[1]]`

Extra arguments to be passed to the consul agent

Default value: `undef`

##### <a name="-consul--group"></a>`group`

Data type: `String[1]`

Name of the group that should own the consul configuration files.

Default value: `$consul::params::group`

##### <a name="-consul--init_style"></a>`init_style`

Data type: `String[1]`

What style of init system your system uses. Set to 'unmanaged' to disable
managing init system files for the consul service entirely.
This is ignored when install_method == 'docker'

Default value: `$consul::params::init_style`

##### <a name="-consul--install_method"></a>`install_method`

Data type: `String[1]`

Valid strings: `docker`  - install via docker container
               `package` - install via system package
               `url`     - download and extract from a url. Defaults to `url`.
               `none`    - disable install.

Default value: `'url'`

##### <a name="-consul--join_wan"></a>`join_wan`

Data type: `Optional[String[1]]`

The wan to join on service start (e.g. 'wan.foo.com'). Defaults to undef (i.e. won't join a wan).

Default value: `undef`

##### <a name="-consul--manage_group"></a>`manage_group`

Data type: `Boolean`

Whether to create/manage the group that should own the consul configuration files.

Default value: `$consul::params::manage_group`

##### <a name="-consul--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Configure the upstream HashiCorp repository. Only relevant when $nomad::install_method = 'package'.

Default value: `$consul::params::manage_repo`

##### <a name="-consul--manage_service"></a>`manage_service`

Data type: `Boolean`

Whether to manage the consul service.

Default value: `true`

##### <a name="-consul--manage_user"></a>`manage_user`

Data type: `Boolean`

Whether to create/manage the user that should own consul's configuration files.

Default value: `$consul::params::manage_user`

##### <a name="-consul--manage_user_home_location"></a>`manage_user_home_location`

Data type: `Boolean`

Whether to explicitly set the location of the consul user's home directory when this modules
manages the creation of the user (aka `manage_user = true`). If the consul user already exists
and this is enabled, puppet tries to change the consul user's home to the new location. This
will cause the puppet run to fail if the consul service is currently running.

Default value: `false`

##### <a name="-consul--manage_data_dir"></a>`manage_data_dir`

Data type: `Boolean`

Whether to manage the consul storage data directory.

Default value: `true`

##### <a name="-consul--os"></a>`os`

Data type: `String[1]`

OS component in the name of the archive file containing the consul binary.

Default value: `$facts['kernel'].downcase`

##### <a name="-consul--package_ensure"></a>`package_ensure`

Data type: `String[1]`

Only valid when the install_method == package. Defaults to `latest`.

Default value: `'latest'`

##### <a name="-consul--package_name"></a>`package_name`

Data type: `String[1]`

Only valid when the install_method == package. Defaults to `consul`.

Default value: `'consul'`

##### <a name="-consul--pretty_config"></a>`pretty_config`

Data type: `Boolean`

Generates a human readable JSON config file. Defaults to `false`.

Default value: `false`

##### <a name="-consul--pretty_config_indent"></a>`pretty_config_indent`

Data type: `Integer`

Toggle indentation for human readable JSON file. Defaults to `4`.

Default value: `4`

##### <a name="-consul--proxy_server"></a>`proxy_server`

Data type: `Optional[Stdlib::HTTPUrl]`

Specify a proxy server, with port number if needed. ie: https://example.com:8080.

Default value: `undef`

##### <a name="-consul--purge_config_dir"></a>`purge_config_dir`

Data type: `Boolean`

Purge config files no longer generated by Puppet

Default value: `true`

##### <a name="-consul--restart_on_change"></a>`restart_on_change`

Data type: `Boolean`

Determines whether to restart consul agent on $config_hash changes.
This will not affect reloads when service, check or watch configs change.

Default value: `true`

##### <a name="-consul--service_enable"></a>`service_enable`

Data type: `Boolean`

Whether to enable the consul service to start at boot.

Default value: `true`

##### <a name="-consul--service_ensure"></a>`service_ensure`

Data type: `Enum['stopped', 'running']`

Whether the consul service should be running or not.

Default value: `'running'`

##### <a name="-consul--services"></a>`services`

Data type: `Hash`

Hash of consul::service resources to create.

Default value: `{}`

##### <a name="-consul--user"></a>`user`

Data type: `String[1]`

Name of the user that should own the consul configuration files.

Default value: `$consul::params::user`

##### <a name="-consul--version"></a>`version`

Data type: `String[1]`

Specify version of consul binary to download.

Default value: `'1.16.3'`

##### <a name="-consul--watches"></a>`watches`

Data type: `Hash`

Hash of consul::watch resources to create.

Default value: `{}`

##### <a name="-consul--shell"></a>`shell`

Data type: `Optional[String[1]]`

The shell for the consul user. Defaults to something that prohibits login, like /usr/sbin/nologin

Default value: `$consul::params::shell`

##### <a name="-consul--enable_beta_ui"></a>`enable_beta_ui`

Data type: `Boolean`

consul 1.1.0 introduced a new UI, which is currently (2018-05-12) in beta status.
You can enable it by setting this variable to true. Defaults to false

Default value: `false`

##### <a name="-consul--allow_binding_to_root_ports"></a>`allow_binding_to_root_ports`

Data type: `Boolean`

enables CAP_NET_BIND_SERVICE if true. This is currently only implemented on systemd nodes

Default value: `false`

##### <a name="-consul--log_file"></a>`log_file`

Data type: `Stdlib::Absolutepath`

where should the log file be located

Default value: `'/var/log/consul'`

## Defined types

### <a name="consul--check"></a>`consul::check`

Sets up a Consul healthcheck

* **See also**
  * http://www.consul.io/docs/agent/checks.html

#### Parameters

The following parameters are available in the `consul::check` defined type:

* [`ensure`](#-consul--check--ensure)
* [`http`](#-consul--check--http)
* [`id`](#-consul--check--id)
* [`interval`](#-consul--check--interval)
* [`notes`](#-consul--check--notes)
* [`script`](#-consul--check--script)
* [`args`](#-consul--check--args)
* [`service_id`](#-consul--check--service_id)
* [`status`](#-consul--check--status)
* [`tcp`](#-consul--check--tcp)
* [`grpc`](#-consul--check--grpc)
* [`timeout`](#-consul--check--timeout)
* [`token`](#-consul--check--token)
* [`ttl`](#-consul--check--ttl)
* [`success_before_passing`](#-consul--check--success_before_passing)
* [`failures_before_critical`](#-consul--check--failures_before_critical)

##### <a name="-consul--check--ensure"></a>`ensure`

Data type: `Any`

Define availability of check. Use 'absent' to remove existing checks

Default value: `present`

##### <a name="-consul--check--http"></a>`http`

Data type: `Any`

HTTP endpoint for the service healthcheck

Default value: `undef`

##### <a name="-consul--check--id"></a>`id`

Data type: `Any`

The id for the check (defaults to $title)

Default value: `$title`

##### <a name="-consul--check--interval"></a>`interval`

Data type: `Any`

Value in seconds for the interval between runs of the check

Default value: `undef`

##### <a name="-consul--check--notes"></a>`notes`

Data type: `Any`

Human readable description of the check

Default value: `undef`

##### <a name="-consul--check--script"></a>`script`

Data type: `Any`

Full path to the location of the healthcheck script. Must be nagios
compliant with regards to the return codes. This parameter is deprecated
in Consul 1.0.0, see https://github.com/hashicorp/consul/issues/3509.

Default value: `undef`

##### <a name="-consul--check--args"></a>`args`

Data type: `Any`

Arguments to be `exec`ed for the healthcheck script.

Default value: `undef`

##### <a name="-consul--check--service_id"></a>`service_id`

Data type: `Any`

An optional service_id to match this check against

Default value: `undef`

##### <a name="-consul--check--status"></a>`status`

Data type: `Any`

The default state of the check when it is registered against a consul agent. Should be either "critical" or "passing"

Default value: `undef`

##### <a name="-consul--check--tcp"></a>`tcp`

Data type: `Any`

The IP/hostname and port for the service healthcheck. Should be in 'hostname:port' format.

Default value: `undef`

##### <a name="-consul--check--grpc"></a>`grpc`

Data type: `Any`

GRPC endpoint for the service healthcheck

Default value: `undef`

##### <a name="-consul--check--timeout"></a>`timeout`

Data type: `Any`

A timeout value for HTTP request only

Default value: `undef`

##### <a name="-consul--check--token"></a>`token`

Data type: `Any`

ACL token for interacting with the catalog (must be 'management' type)

Default value: `undef`

##### <a name="-consul--check--ttl"></a>`ttl`

Data type: `Any`

Value in seconds before the http endpoint considers a failing healthcheck to be "HARD" down.

Default value: `undef`

##### <a name="-consul--check--success_before_passing"></a>`success_before_passing`

Data type: `Any`

Value may be set to become check passing only after a specified number of consecutive checks return passing

Default value: `undef`

##### <a name="-consul--check--failures_before_critical"></a>`failures_before_critical`

Data type: `Any`

Value may be set to become check critical only after a specified number of consecutive checks return critical

Default value: `undef`

### <a name="consul--service"></a>`consul::service`

Sets up a Consul service definition

* **See also**
  * http://www.consul.io/docs/agent/services.html

#### Examples

##### simple MySQL service

```puppet
consul::service { 'my_db':
  port                => 3306,
  tags                => ['db','mysql'],
  address             => '1.2.3.4',
  token               => 'xxxxxxxxxx',
  service_config_hash =>  {
    'connect' => {
      'sidecar_service' => {},
    },
  },
  checks              => [
    {
      name     => 'MySQL Port',
      tcp      => 'localhost:3306',
      interval => '10s',
    },
  ],
}
```

##### simple HTTPS service

```puppet
consul::service { 'my_https_app':
  port                => 443,
  tags                => ['web','rails'],
  address             => '1.2.3.5',
  token               => 'xxxxxxxxxx',
  service_config_hash =>  {
    'connect' => {
      'sidecar_service' => {},
    },
  },
  checks              => [
    {
      name            => 'HTTPS Request',
      http            => 'https://localhost:443',
      tls_skip_verify => true,
      method          => "GET",
      headers         => { "Host" => ["test.example.com"] },
    },
  ],
}
```

#### Parameters

The following parameters are available in the `consul::service` defined type:

* [`address`](#-consul--service--address)
* [`checks`](#-consul--service--checks)
* [`enable_tag_override`](#-consul--service--enable_tag_override)
* [`ensure`](#-consul--service--ensure)
* [`id`](#-consul--service--id)
* [`port`](#-consul--service--port)
* [`service_name`](#-consul--service--service_name)
* [`service_config_hash`](#-consul--service--service_config_hash)
* [`tags`](#-consul--service--tags)
* [`token`](#-consul--service--token)
* [`meta`](#-consul--service--meta)

##### <a name="-consul--service--address"></a>`address`

Data type: `Optional[String[1]]`

IP address the service is running at.

Default value: `undef`

##### <a name="-consul--service--checks"></a>`checks`

Data type: `Array[Hash]`

If provided an array of checks that will be added to this service

Default value: `[]`

##### <a name="-consul--service--enable_tag_override"></a>`enable_tag_override`

Data type: `Boolean`

enable_tag_override support for service. Defaults to False.

Default value: `false`

##### <a name="-consul--service--ensure"></a>`ensure`

Data type: `String[1]`

Define availability of service. Use 'absent' to remove existing services. Defaults to 'present'

Default value: `'present'`

##### <a name="-consul--service--id"></a>`id`

Data type: `String[1]`

The unique ID of the service on the node. Defaults to title.

Default value: `$title`

##### <a name="-consul--service--port"></a>`port`

Data type: `Optional[Integer[0, 65535]]`

TCP port the service runs on.

Default value: `undef`

##### <a name="-consul--service--service_name"></a>`service_name`

Data type: `String[1]`

Name of the service. Defaults to title.

Default value: `$title`

##### <a name="-consul--service--service_config_hash"></a>`service_config_hash`

Data type: `Hash`

Use this to populate the basic service params for each of the services

Default value: `{}`

##### <a name="-consul--service--tags"></a>`tags`

Data type: `Array[String[1]]`

Array of strings.

Default value: `[]`

##### <a name="-consul--service--token"></a>`token`

Data type: `Optional[String[1]]`

ACL token for interacting with the catalog (must be 'management' type)

Default value: `undef`

##### <a name="-consul--service--meta"></a>`meta`

Data type:

```puppet
Optional[Hash[
      String[1],
      Variant[
        String[1],
        Numeric,
        Boolean,
  ]]]
```

Service meta key/value pairs as hash.

Default value: `undef`

### <a name="consul--watch"></a>`consul::watch`

Sets up Consul watch, to span commands when data changes.

* **See also**
  * http://www.consul.io/docs/agent/watches.html
  * https://github.com/hashicorp/consul/issues/3509

#### Parameters

The following parameters are available in the `consul::watch` defined type:

* [`datacenter`](#-consul--watch--datacenter)
* [`ensure`](#-consul--watch--ensure)
* [`event_name`](#-consul--watch--event_name)
* [`handler`](#-consul--watch--handler)
* [`args`](#-consul--watch--args)
* [`key`](#-consul--watch--key)
* [`keyprefix`](#-consul--watch--keyprefix)
* [`passingonly`](#-consul--watch--passingonly)
* [`service`](#-consul--watch--service)
* [`service_tag`](#-consul--watch--service_tag)
* [`state`](#-consul--watch--state)
* [`token`](#-consul--watch--token)
* [`type`](#-consul--watch--type)

##### <a name="-consul--watch--datacenter"></a>`datacenter`

Data type: `Any`

String overriding consul's default datacenter.

Default value: `undef`

##### <a name="-consul--watch--ensure"></a>`ensure`

Data type: `Any`

Define availability of watch. Use 'absent' to remove existing watches.

Default value: `present`

##### <a name="-consul--watch--event_name"></a>`event_name`

Data type: `Any`

Name of an event to watch for.

Default value: `undef`

##### <a name="-consul--watch--handler"></a>`handler`

Data type: `Any`

Full path to the script that will be excuted. This parameter is deprecated in Consul 1.0.0

Default value: `undef`

##### <a name="-consul--watch--args"></a>`args`

Data type: `Any`

Arguments to be `exec`ed for the watch.

Default value: `undef`

##### <a name="-consul--watch--key"></a>`key`

Data type: `Any`

Watch a specific key.

Default value: `undef`

##### <a name="-consul--watch--keyprefix"></a>`keyprefix`

Data type: `Any`

Watch a whole keyprefix

Default value: `undef`

##### <a name="-consul--watch--passingonly"></a>`passingonly`

Data type: `Optional[Boolean]`

Watch only those services that are passing healthchecks.

Default value: `undef`

##### <a name="-consul--watch--service"></a>`service`

Data type: `Any`

Watch a particular service

Default value: `undef`

##### <a name="-consul--watch--service_tag"></a>`service_tag`

Data type: `Any`

This actually maps to the "tag" param for service watches. (`tag` is a puppet builtin metaparameter)

Default value: `undef`

##### <a name="-consul--watch--state"></a>`state`

Data type: `Any`

Watch a state change on a service healthcheck.

Default value: `undef`

##### <a name="-consul--watch--token"></a>`token`

Data type: `Any`

String to override the default token.

Default value: `undef`

##### <a name="-consul--watch--type"></a>`type`

Data type: `Any`

Type of data to watch. (Like key, service, services, nodes)

Default value: `undef`

## Resource types

### <a name="consul_acl"></a>`consul_acl`

Manage a consul token and its ACLs.

#### Properties

The following properties are available in the `consul_acl` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `id`

ID of token

##### `protocol`

Valid values: `http`, `https`

consul protocol

Default value: `http`

##### `rules`

hash of ACL rules for this token

##### `type`

Valid values: `client`, `management`

Type of token

Default value: `client`

#### Parameters

The following parameters are available in the `consul_acl` type.

* [`acl_api_token`](#-consul_acl--acl_api_token)
* [`api_tries`](#-consul_acl--api_tries)
* [`hostname`](#-consul_acl--hostname)
* [`name`](#-consul_acl--name)
* [`port`](#-consul_acl--port)
* [`provider`](#-consul_acl--provider)

##### <a name="-consul_acl--acl_api_token"></a>`acl_api_token`

Token for accessing the ACL API

Default value: `anonymous`

##### <a name="-consul_acl--api_tries"></a>`api_tries`

number of tries when contacting the Consul REST API

Default value: `3`

##### <a name="-consul_acl--hostname"></a>`hostname`

consul hostname

Default value: `localhost`

##### <a name="-consul_acl--name"></a>`name`

namevar

Name of the token

##### <a name="-consul_acl--port"></a>`port`

consul port

Default value: `8500`

##### <a name="-consul_acl--provider"></a>`provider`

The specific backend to use for this `consul_acl` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="consul_key_value"></a>`consul_key_value`

Manage a consul key value object.

#### Properties

The following properties are available in the `consul_key_value` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

The key value string

#### Parameters

The following parameters are available in the `consul_key_value` type.

* [`acl_api_token`](#-consul_key_value--acl_api_token)
* [`api_tries`](#-consul_key_value--api_tries)
* [`datacenter`](#-consul_key_value--datacenter)
* [`flags`](#-consul_key_value--flags)
* [`hostname`](#-consul_key_value--hostname)
* [`name`](#-consul_key_value--name)
* [`port`](#-consul_key_value--port)
* [`protocol`](#-consul_key_value--protocol)
* [`provider`](#-consul_key_value--provider)

##### <a name="-consul_key_value--acl_api_token"></a>`acl_api_token`

Token for accessing the ACL API

Default value: `anonymous`

##### <a name="-consul_key_value--api_tries"></a>`api_tries`

number of tries when contacting the Consul REST API

Default value: `3`

##### <a name="-consul_key_value--datacenter"></a>`datacenter`

Name of the datacenter to query. If unspecified, the query will default to the datacenter of the Consul agent at the
HTTP address.

Default value: `''`

##### <a name="-consul_key_value--flags"></a>`flags`

Flags integer

Default value: `0`

##### <a name="-consul_key_value--hostname"></a>`hostname`

consul hostname

Default value: `localhost`

##### <a name="-consul_key_value--name"></a>`name`

namevar

Name of the key/value object

##### <a name="-consul_key_value--port"></a>`port`

consul port

Default value: `8500`

##### <a name="-consul_key_value--protocol"></a>`protocol`

Valid values: `http`, `https`

consul protocol

Default value: `http`

##### <a name="-consul_key_value--provider"></a>`provider`

The specific backend to use for this `consul_key_value` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="consul_policy"></a>`consul_policy`

Manages a Consul ACL policy

#### Properties

The following properties are available in the `consul_policy` type.

##### `datacenters`

List of datacenter names assigned to the policy

Default value: `[]`

##### `description`

Description of the policy

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `id`

ID of already existing policy

Default value: `''`

##### `rules`

List of ACL rules for this policy

Default value: `[]`

#### Parameters

The following parameters are available in the `consul_policy` type.

* [`acl_api_token`](#-consul_policy--acl_api_token)
* [`api_tries`](#-consul_policy--api_tries)
* [`hostname`](#-consul_policy--hostname)
* [`name`](#-consul_policy--name)
* [`port`](#-consul_policy--port)
* [`protocol`](#-consul_policy--protocol)
* [`provider`](#-consul_policy--provider)

##### <a name="-consul_policy--acl_api_token"></a>`acl_api_token`

Token for accessing the ACL API

Default value: `''`

##### <a name="-consul_policy--api_tries"></a>`api_tries`

number of tries when contacting the Consul REST API

Default value: `3`

##### <a name="-consul_policy--hostname"></a>`hostname`

consul hostname

Default value: `localhost`

##### <a name="-consul_policy--name"></a>`name`

namevar

Name of the policy

##### <a name="-consul_policy--port"></a>`port`

consul port

Default value: `8500`

##### <a name="-consul_policy--protocol"></a>`protocol`

Valid values: `http`, `https`

consul protocol

Default value: `http`

##### <a name="-consul_policy--provider"></a>`provider`

The specific backend to use for this `consul_policy` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="consul_prepared_query"></a>`consul_prepared_query`

Manage a consul prepared query.

#### Properties

The following properties are available in the `consul_prepared_query` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `id`

ID of prepared query

#### Parameters

The following parameters are available in the `consul_prepared_query` type.

* [`acl_api_token`](#-consul_prepared_query--acl_api_token)
* [`api_tries`](#-consul_prepared_query--api_tries)
* [`hostname`](#-consul_prepared_query--hostname)
* [`name`](#-consul_prepared_query--name)
* [`node_meta`](#-consul_prepared_query--node_meta)
* [`port`](#-consul_prepared_query--port)
* [`protocol`](#-consul_prepared_query--protocol)
* [`provider`](#-consul_prepared_query--provider)
* [`service_failover_dcs`](#-consul_prepared_query--service_failover_dcs)
* [`service_failover_n`](#-consul_prepared_query--service_failover_n)
* [`service_meta`](#-consul_prepared_query--service_meta)
* [`service_name`](#-consul_prepared_query--service_name)
* [`service_near`](#-consul_prepared_query--service_near)
* [`service_only_passing`](#-consul_prepared_query--service_only_passing)
* [`service_tags`](#-consul_prepared_query--service_tags)
* [`template`](#-consul_prepared_query--template)
* [`template_regexp`](#-consul_prepared_query--template_regexp)
* [`template_type`](#-consul_prepared_query--template_type)
* [`token`](#-consul_prepared_query--token)
* [`ttl`](#-consul_prepared_query--ttl)

##### <a name="-consul_prepared_query--acl_api_token"></a>`acl_api_token`

Token for accessing the ACL API

Default value: `anonymous`

##### <a name="-consul_prepared_query--api_tries"></a>`api_tries`

number of tries when contacting the Consul REST API

Default value: `3`

##### <a name="-consul_prepared_query--hostname"></a>`hostname`

consul hostname

Default value: `localhost`

##### <a name="-consul_prepared_query--name"></a>`name`

namevar

Name of the prepared query

##### <a name="-consul_prepared_query--node_meta"></a>`node_meta`

List of user-defined key/value pairs to filter on NodeMeta

##### <a name="-consul_prepared_query--port"></a>`port`

consul port

Default value: `8500`

##### <a name="-consul_prepared_query--protocol"></a>`protocol`

Valid values: `http`, `https`

consul protocol

Default value: `http`

##### <a name="-consul_prepared_query--provider"></a>`provider`

The specific backend to use for this `consul_prepared_query` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-consul_prepared_query--service_failover_dcs"></a>`service_failover_dcs`

List of datacenters to forward queries to if no health services found locally

Default value: `[]`

##### <a name="-consul_prepared_query--service_failover_n"></a>`service_failover_n`

Failover to the nearest <n> datacenters

Default value: `0`

##### <a name="-consul_prepared_query--service_meta"></a>`service_meta`

List of user-defined key/value pairs to filter on ServiceMeta

##### <a name="-consul_prepared_query--service_name"></a>`service_name`

Service name for the prepared query

##### <a name="-consul_prepared_query--service_near"></a>`service_near`

Resurn results in ascending order of estimated RTT from given node name, or _agent special value

Default value: `''`

##### <a name="-consul_prepared_query--service_only_passing"></a>`service_only_passing`

Only return services in the passing state

Default value: `false`

##### <a name="-consul_prepared_query--service_tags"></a>`service_tags`

List of tags to filter the query with

Default value: `[]`

##### <a name="-consul_prepared_query--template"></a>`template`

Valid values: `true`, `false`, `yes`, `no`

is template?

Default value: `false`

##### <a name="-consul_prepared_query--template_regexp"></a>`template_regexp`

regexp for template

Default value: `''`

##### <a name="-consul_prepared_query--template_type"></a>`template_type`

type for template

Default value: `name_prefix_match`

##### <a name="-consul_prepared_query--token"></a>`token`

The prepared query token

Default value: `''`

##### <a name="-consul_prepared_query--ttl"></a>`ttl`

TTL for the DNS lookup

Default value: `0`

### <a name="consul_token"></a>`consul_token`

Manages a v2 Consul token

#### Properties

The following properties are available in the `consul_token` type.

##### `accessor_id`

Accessor ID of the token

##### `description`

Description of the token

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `policies_by_id`

List of policy IDs assigned to the token

Default value: `[]`

##### `policies_by_name`

List of policy names assigned to the token

Default value: `[]`

##### `secret_id`

Secret ID of the token

Default value: `''`

#### Parameters

The following parameters are available in the `consul_token` type.

* [`acl_api_token`](#-consul_token--acl_api_token)
* [`api_tries`](#-consul_token--api_tries)
* [`hostname`](#-consul_token--hostname)
* [`name`](#-consul_token--name)
* [`port`](#-consul_token--port)
* [`protocol`](#-consul_token--protocol)
* [`provider`](#-consul_token--provider)

##### <a name="-consul_token--acl_api_token"></a>`acl_api_token`

Token for accessing the ACL API

Default value: `''`

##### <a name="-consul_token--api_tries"></a>`api_tries`

number of tries when contacting the Consul REST API

Default value: `3`

##### <a name="-consul_token--hostname"></a>`hostname`

consul hostname

Default value: `localhost`

##### <a name="-consul_token--name"></a>`name`

namevar

Name of the token

##### <a name="-consul_token--port"></a>`port`

consul port

Default value: `8500`

##### <a name="-consul_token--protocol"></a>`protocol`

Valid values: `http`, `https`

consul protocol

Default value: `http`

##### <a name="-consul_token--provider"></a>`provider`

The specific backend to use for this `consul_token` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Functions

### <a name="consul--sorted_json"></a>`consul::sorted_json`

Type: Ruby 4.x API

The consul::sorted_json function.

#### `consul::sorted_json(Optional[Any] $unsorted_hash = {}, Optional[Any] $pretty = false, Optional[Any] $indent_len = 4)`

The consul::sorted_json function.

Returns: `Any`

##### `unsorted_hash`

Data type: `Optional[Any]`



##### `pretty`

Data type: `Optional[Any]`



##### `indent_len`

Data type: `Optional[Any]`



### <a name="consul--validate_checks"></a>`consul::validate_checks`

Type: Ruby 4.x API

The consul::validate_checks function.

#### `consul::validate_checks(HashOrArray $obj)`

The consul::validate_checks function.

Returns: `Any`

##### `obj`

Data type: `HashOrArray`



## Data types

### <a name="Consul--PolicyStruct"></a>`Consul::PolicyStruct`

The Consul::PolicyStruct data type.

Alias of

```puppet
Struct[{
    id            => Optional[String[1]],
    ensure        => Optional[Enum['present', 'absent']],
    description   => Optional[String[0]],
    datacenters   => Optional[Array[String[1]]],
    rules         => Optional[Array[Struct[{
            resource    => String[1],
            segment     => Optional[String[0]],
            disposition => String[1],
    }]]],
    acl_api_token => Optional[String[1]],
    protocol      => Optional[String[1]],
    port          => Optional[Integer[1, 65535]],
    hostname      => Optional[String[1]],
    api_tries     => Optional[Integer[1]],
  }]
```

### <a name="Consul--TokenStruct"></a>`Consul::TokenStruct`

The Consul::TokenStruct data type.

Alias of

```puppet
Struct[{
    description      => Optional[String[0]],
    accessor_id      => String[1],
    ensure           => Optional[Enum['present', 'absent']],
    secret_id        => Optional[String[1]],
    policies_by_name => Optional[Array[String]],
    policies_by_id   => Optional[Array[String]],
    acl_api_token    => Optional[String[1]],
    protocol         => Optional[String[1]],
    port             => Optional[Integer[1, 65535]],
    hostname         => Optional[String[1]],
    api_tries        => Optional[Integer[1]],
  }]
```

